For a more detailed changelog see [CHANGELOG](https://github.com/kschweiger/track_analyzer/blob/main/CHANGELOG.md) on GitHub
## [1.1.2](https://github.com/kschweiger/track_analyzer/releases/tag/1.1.2)
### [1.1.2](https://github.com/kschweiger/track_analyzer/compare/1.0.0...1.1.2) (2024-01-14)

#### Features

- Convert model dataclasses to pydantic models  (#16) ([488600b](https://github.com/kschweiger/track_analyzer/commit/488600b9e069a3a4234abb20d09469ea508629a9))
- enhance-elevation cli (#15) ([9318d93](https://github.com/kschweiger/track_analyzer/commit/9318d93612ad3aa01673c385a8d8cae36487d5d3))
- **visualize:** Adding function for plotting data of multiple tracks ([9b96054](https://github.com/kschweiger/track_analyzer/commit/9b96054e1fe5b75e682954e2db5de01ac1e6da06))


<a name="1.1.1"></a>

----------------------------

## [1.0.0](https://github.com/kschweiger/track_analyzer/releases/tag/1.0.0)
### [1.0.0](https://github.com/kschweiger/track_analyzer/compare/0.5.3...1.0.0) (2023-12-04)

Release of first non-development version of the package on PyPi 🎉

<a name="0.5.3"></a>

**Full Changelog**: https://github.com/kschweiger/track_analyzer/compare/0.5.3...1.0.0

----------------------------

## [0.5.1](https://github.com/kschweiger/track_analyzer/releases/tag/0.5.1)
### [0.5.1](https://github.com/kschweiger/track_analyzer/compare/0.5.0...0.5.1) (2023-12-03)

<a name="0.5.0"></a>

### [0.5.0](https://github.com/kschweiger/track_analyzer/compare/0.4.1...0.5.0) (2023-12-03)

#### Features

- Interpolation includes extentions heartrate, cadence, power (#13) ([e777fa1](https://github.com/kschweiger/track_analyzer/commit/e777fa1505b28fc3e626ecb0fdcaba23ebaa0231))
- **visualize.map:** Adding map_style and line_width for map plot functions ([0beaec2](https://github.com/kschweiger/track_analyzer/commit/0beaec264093dd03c11e3e755a9b70d7aa6dbcb1))
- **Track:** Adding split method (#11) ([3ac4a42](https://github.com/kschweiger/track_analyzer/commit/3ac4a427f2a46300c6aba56f58b44a6a5e953e51))
- **Track:** Added plot method (#9) ([d71b888](https://github.com/kschweiger/track_analyzer/commit/d71b88821ae48b6b6bf2348ddad8793ad21a5f74))

#### Bug Fixes

- **plot_segments_on_map:** Plot now works with tracks w/o time ([4789ddb](https://github.com/kschweiger/track_analyzer/commit/4789ddb300ceadd1907a9ab402a11a5068703581))
- Track DataFrame with multiple segments was missing datapoints ([975f1f9](https://github.com/kschweiger/track_analyzer/commit/975f1f9f5e695fe11cd1c38740692aa4282a62dd))

#### Code Refactoring

- Renamed package to geo-track-analyzer ([13779ef](https://github.com/kschweiger/track_analyzer/commit/13779eff5622d3351cb0143419adf7bf0e902acf))


----------------------------
